@@ -141,7 +141,7 @@
 //'   Cholesky factorization (`t(chol(sigma))`)
 //'   of the covariance matrix of volatility
 //'   or randomness in the process
-//'   \eqn{\boldsymbol{\Sigma}}.
+//'   (\eqn{\boldsymbol{\Sigma}}).
 //' @param delta_t Numeric.
 //'   Time interval
 //'   (\eqn{\Delta_t}).
@@ -191,21 +191,35 @@
 //' )
 //'
 //' @family Simulation of State Space Models Data Functions
-//' @keywords simStateSpace sim linsde
+//' @keywords simStateSpace transformation linsde
 //' @export
 // [[Rcpp::export]]
 Rcpp::List LinSDE2SSM(const arma::vec& iota, const arma::mat& phi,
                       const arma::mat& sigma_l, const double delta_t) {
   int p = iota.n_elem;
-  arma::mat I = arma::eye<arma::mat>(p, p);
-  arma::mat J = arma::eye<arma::mat>(p * p, p * p);
-  arma::mat phi_hashtag = arma::kron(phi, I) + arma::kron(I, phi);
-  arma::vec sigma_vec = arma::vectorise(sigma_l * sigma_l.t());
-  arma::vec psi_vec = arma::inv(phi_hashtag) *
-                      (arma::expmat(phi_hashtag * delta_t) - J) * sigma_vec;
-  arma::mat psi_l = arma::chol(arma::reshape(psi_vec, p, p), "lower");
+  arma::mat I = arma::eye(p, p);
+  // beta
   arma::mat beta = arma::expmat(phi * delta_t);
-  arma::vec alpha = arma::inv(phi) * (beta - I) * iota;
+  // alpha
+  arma::vec alpha = arma::vec(p);
+  if (arma::all(iota == 0)) {
+    alpha = iota;
+  } else {
+    alpha = arma::inv(phi) * (beta - I) * iota;
+  }
+  // psi_l
+  arma::mat psi_l = arma::mat(p, p);
+  if (arma::all(arma::vectorise(sigma_l) == 0)) {
+    psi_l = sigma_l;
+  } else {
+    arma::mat J = arma::eye(p * p, p * p);
+    arma::mat phi_hashtag = arma::kron(phi, I) + arma::kron(I, phi);
+    arma::vec sigma_vec = arma::vectorise(sigma_l * sigma_l.t());
+    arma::vec psi_vec = arma::inv(phi_hashtag) *
+                        (arma::expmat(phi_hashtag * delta_t) - J) * sigma_vec;
+    psi_l = arma::chol(arma::reshape(psi_vec, p, p), "lower");
+  }
+  // output
   return Rcpp::List::create(Rcpp::Named("alpha") = alpha,
                             Rcpp::Named("beta") = beta,
                             Rcpp::Named("psi_l") = psi_l);
